
'''

|logo| Python SDK Reference
~~~~~~~~~~~~~~~~~~~~~~~~~~~

The following table lists the Python SDK modules and classes:

`satori.rtm.client`_
    Provides a higher-level API that automatically reconnects
    to RTM in the event of a disconnection.
`satori.rtm.connection`_
    Provides a low-level API for managing a connection to RTM.
`satori.rtm.auth`_
    Provides the delegate object to be used when authenticating
    clients with RTM.
`satori.rtm.logger`_
    Logging module for the Python SDK.

.. |logo| image:: https://www.satori.com/assets/images/logo-light@2x.png
          :height: 30px
          :width: 177px
          :alt: Satori
          :target: https://www.satori.com
          :align: middle
'''
